@@ -2,6 +2,7 @@
 use crate::pg_num::PgU8;
 use crate::user::{ShortUser, UserIdRef};
 use chrono::{DateTime, Utc};
+use enum_iterator::IntoEnumIterator;
 #[cfg(feature = "_serde")]
 use etwin_serde_tools::{serialize_instant, serialize_opt_instant, Deserialize, Serialize, Serializer};
 #[cfg(feature = "sqlx")]
@@ -14,6 +15,26 @@ use std::ops::{Range, RangeFrom};
 #[cfg(feature = "sqlx")]
 use thiserror::Error;
 
+pub type HtmlFragment = String;
+
+declare_new_enum!(
+  #[derive(IntoEnumIterator)]
+  pub enum LocaleId {
+    #[str("de-DE")]
+    DeDe,
+    #[str("en-US")]
+    EnUs,
+    #[str("eo")]
+    Eo,
+    #[str("es-SP")]
+    EsSp,
+    #[str("fr-FR")]
+    FrFr,
+  }
+  pub type ParseError = LocaleIdParseError;
+  const SQL_NAME = "locale_id";
+);
+
 pub type Instant = DateTime<Utc>;
 
 /// Private type used to serialize PeriodLower and its variants.
@@ -239,6 +260,7 @@ pub struct RawUserDot {
   pub user: UserIdRef,
 }
 
+// TODO SecretString/SecretBytes
 #[derive(Clone)]
 pub struct Secret(String);
 
