@@ -9,11 +9,13 @@ pub mod auth;
 pub mod clock;
 pub mod core;
 pub mod dinoparc;
+pub mod dinorpg;
 pub mod email;
 pub mod hammerfest;
 pub mod link;
 pub mod oauth;
 pub mod password;
+pub mod popotamo;
 pub mod temporal;
 pub mod token;
 pub mod twinoid;
